# Copyright (C) 2022 Panther Labs Inc
#
# Panther Enterprise is licensed under the terms of a commercial license available from
# Panther Labs Inc ("Panther Commercial License") by contacting contact@runpanther.com.
# All use, distribution, and/or modification of this software, whether commercial or non-commercial,
# falls under the Panther Commercial License to the extent it is permitted.

# coding=utf-8
# *** WARNING: generated file
"""
The Panther Python Config SDK defines dataclasses that represent various objects in a Panther instance
"""

from panther_core import PantherEvent

__all__ = [
    "PantherEvent",
    "testing",
    "detection",
    "query",
]

from . import (
    testing,
    detection,
    query,
)
